==> k4de-0.3.0.tgz: k4de-0.3.0/src/kde/texture/transformationswidget.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** transformationswidget.h
*/
#ifndef __TRANSFORMATIONSWIDGET_H__
#define __TRANSFORMATIONSWIDGET_H__


#include <qwidget.h>
#include <qgroupbox.h>
#include <qpainter.h>
#include <qcolor.h>
#include <kcolorbtn.h>
#include <qdialog.h>
#include <qlineedit.h>

#include "../misc/vectorwidget.h"
#include "../../3d/textures/transformations.h"


class TransformationsWidget : public QDialog
{
Q_OBJECT
protected:
	Transformations *tr,trb;
	QPushButton *ok,*cancel;
	VectorWidget *scale,*rotate,*translate;

protected slots:
	void OkPressed();
	void CancelPressed();
	
public:

	TransformationsWidget(QWidget *p,Transformations *);
	~TransformationsWidget();

	void getTransformations();

	void	paintEvent(QPaintEvent*);
	int	exec();

};


#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/kde/texture/transformationswidget.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** transformationswidget.h
*/
#ifndef __TRANSFORMATIONSWIDGET_H__
#define __TRANSFORMATIONSWIDGET_H__


#include <qwidget.h>
#include <qgroupbox.h>
#include <qpainter.h>
#include <qcolor.h>
#include <kcolorbtn.h>
#include <qdialog.h>
#include <qlineedit.h>
#include <klocale.h>
#include <misc.h>

#include "../widgets/vectorwidget.h"
#include "../../3d/textures/transformations.h"

#include "../widgets/tabwidget.h"

#include "texturewidgetbase.h"

class TransformationsWidget : public TextureWidgetBase
{
Q_OBJECT
protected:
	Transformations *tr,trb;
	VectorWidget *scale,*rotate,*translate;

	TabWidget	*tab;
	QSize 	qs;

public:

	TransformationsWidget(QWidget *p,Transformations *);
	~TransformationsWidget();

	virtual void getValue();
	virtual QSize sizeHint() const;

	void	getTransformations();

	void	paintEvent(QPaintEvent*);
	int	exec();
};


#endif
